# Welcome to Uvicore

The Full Stack Asynchronous Python Framework with the performance of FastAPI and the elegance of Laravel!

## About Uvicore

Uvicore is a fullstack async API, Web and CLI python framework.  Uvicore is built on great technologies such as:

- Simple and fast routing engine thanks to FastAPI and Starlette.
- Full Async/Await python everywhere, even at the CLI thanks to AsyncClick.
- Powerful IoC container so your App controls the framework and can override anything.
- Adapter pattens for multiple backends to caching, auth, events, databases and more.
- Robust modular and deep-merged config system across uvicore modules.
- Custom and expressive ORM built on top of SQLAlchemy Core.

Uvicore is the missing fullstack asynchronous framework for elegant and rapid python development.



## Learning Uvicore

Uvicore documentation is still underway, but you can get started today at https://uvicore.io


## Quick Start Installation

**Installation**
```bash
wget https://raw.githubusercontent.com/uvicore/framework/master/bin/uvicore-installer
mv uvicore-installer /usr/local/bin
chmod a+x /usr/local/bin/uvicore-installer

cd ~/Code
uvicore-installer  # To see help
uvicore-installer ./blog

# Follow the post-installation instructions.
```


## License

The Laravel framework is open-sourced software licensed under the [MIT license](https://mreschke.com/license/mit).
